@@ -33,7 +33,7 @@ function(WT, my.series = 1, lvl = 0,
     ## Identify the scenario
     ####################################
     
-    if (class(WT) == 'analyze.wavelet') {
+    if (inherits(WT, 'analyze.wavelet')) {
     
         out("Your input object class is 'analyze.wavelet'...\n") 
         
@@ -45,7 +45,7 @@ function(WT, my.series = 1, lvl = 0,
         Ridge = WT$Ridge     
         
     } 
-    if (class(WT) == 'analyze.coherency') {   
+    if (inherits(WT, 'analyze.coherency')) {
     
         out("Your input object class is 'analyze.coherency'...\n")   
         
