@@ -34,7 +34,7 @@ function(WT, my.series = 1, exponent = 1,
   
   series.data = WT$series
     
-  if (class(WT) == 'analyze.wavelet') {
+  if (inherits(WT, 'analyze.wavelet')) {
     
       out("Your input object class is 'analyze.wavelet'...\n")       
       
@@ -44,7 +44,7 @@ function(WT, my.series = 1, exponent = 1,
       Power.avg.pval = WT$Power.avg.pval   
         
   } 
-  if (class(WT) == 'analyze.coherency') {   
+  if (inherits(WT, 'analyze.coherency')) {
     
       out("Your input object class is 'analyze.coherency'...\n") 
             
