@@ -52,7 +52,7 @@ function(WT, my.series = 1, exponent = 1,
   ## Identify the scenario
   ####################################
     
-  if (class(WT) == 'analyze.wavelet') {
+  if (inherits(WT, 'analyze.wavelet')) {
     
       out("Your input object class is 'analyze.wavelet'...\n") 
          
@@ -63,7 +63,7 @@ function(WT, my.series = 1, exponent = 1,
       Ridge = WT$Ridge     
         
   } 
-  if (class(WT) == 'analyze.coherency') {   
+  if (inherits(WT, 'analyze.coherency')) {
     
       out("Your input object class is 'analyze.coherency'...\n") 
         
