@@ -35,7 +35,7 @@ function(WT, my.series = 1,
    ## Identify the scenario
    ####################################
   
-   if (class(WT) == 'analyze.wavelet') {
+   if (inherits(WT, 'analyze.wavelet')) {
     
       out("Your input object class is 'analyze.wavelet'...\n")       
       
@@ -45,7 +45,7 @@ function(WT, my.series = 1,
       Power.pval = WT$Power.pval   
         
   } 
-  if (class(WT) == 'analyze.coherency') {   
+  if (inherits(WT, 'analyze.coherency')) {
     
       out("Your input object class is 'analyze.coherency'...\n") 
             
@@ -533,4 +533,4 @@ function(WT, my.series = 1,
      
   return(invisible(output))  
   
-}
\ No newline at end of file
+}
